@@ -73,9 +73,18 @@ class ExBaseModel(BaseModel):
     def update(self):
         self.texture.use(location=0)
         [vao[0].program['camPos'].write(self.app.camera.position) for vao in self.vao.vaos]
+        [vao[0].program['view'].write(glm.int8(self.app.camera.view)) for vao in self.vao.vaos]
         [vao[0].program['m_view'].write(self.app.camera.m_view) for vao in self.vao.vaos]
         [vao[0].program['m_model'].write(self.m_model) for vao in self.vao.vaos]
 
+        [vao[1].program['m_proj'].write(self.camera.m_proj) for vao in self.vao.vaos]
+        [vao[1].program['m_view_light'].write(self.app.light.m_view_light) for vao in self.vao.vaos]
+
+        [vao[0].program['m_proj'].write(self.app.camera.m_proj) for vao in self.vao.vaos]
+        #fog = max(min((glm.distance(self.app.camera.position, self.pos) - 100)/20, 1.0), 0);
+        #print(fog)
+        #[vao[0].program['fog'].write(glm.float64(fog)) for vao in self.vao.vaos]
+
     def update_shadow(self):
         [vao[1].program['m_model'].write(self.m_model) for vao in self.vao.vaos]
 
@@ -85,7 +94,6 @@ class ExBaseModel(BaseModel):
 
     def on_init(self):
         [vao[0].program['m_view_light'].write(self.app.light.m_view_light) for vao in self.vao.vaos]
-
         [vao[0].program['u_resolution'].write(glm.vec2(self.app.size)) for vao in self.vao.vaos]
 
         self.depth_texture = self.app.mesh.texture.textures['dt']
@@ -103,7 +111,6 @@ class ExBaseModel(BaseModel):
         [vao[0].program['m_proj'].write(self.app.camera.m_proj) for vao in self.vao.vaos]
         [vao[0].program['m_view'].write(self.app.camera.m_view) for vao in self.vao.vaos]
         [vao[0].program['m_model'].write(self.m_model) for vao in self.vao.vaos]
-
         [vao[0].program['light.position'].write(self.app.light.position) for vao in self.vao.vaos]
         [vao[0].program['light.Ia'].write(self.app.light.Ia) for vao in self.vao.vaos]
         [vao[0].program['light.Id'].write(self.app.light.Id) for vao in self.vao.vaos]
