@@ -102,30 +102,6 @@ class GraphicsEngine:
 
         def destroy(self): self.depth_fbo.release()
 
-    class Pointer():
-        def __init__(self, cam, pos):
-            self.cam = cam
-            self.pos = pos
-            self.fov = cam.FOV
-            self.nfov = self.fov//cam.aspect_ratio
-            self.angle = [0, 0]
-            self.fa = 0
-
-        def behind(self):
-            toOther = self.pos - self.cam.position
-            return glm.dot(self.cam.forward, toOther) < 0
-
-        def update(self):
-            pos = self.cam.position
-            self.fa = math.degrees(math.atan2(self.pos.y - pos.y, self.pos.x - pos.x))
-            self.fa += self.cam.yaw
-            self.fb = math.degrees(math.atan2(self.pos.y - pos.y, self.pos.z - pos.z))
-            self.fb += self.cam.pitch
-            posn = [li(((cos(-self.fov), sin(-self.fov)), (cos(0), sin(0))), ((0, 0), (cos(-self.fa), sin(-self.fa)))), li(((cos(-self.nfov), sin(-self.nfov)), (cos(0), sin(0))), ((0, 0), (cos(-self.fb), sin(-self.fb))))]
-            m = l((cos(-self.fov), sin(-self.fov)), posn[0]) / l((cos(-self.fov), sin(-self.fov)), (cos(0), sin(0)))
-            m1 = l((cos(-self.nfov), sin(-self.nfov)), posn[1]) / l((cos(-self.nfov), sin(-self.nfov)), (cos(0), sin(0)))
-            self.angle = [m, m1]
-
     def quit(self):
         self.mesh.destroy()
         self.scene.destroy()
@@ -141,8 +117,8 @@ class GraphicsEngine:
 
         pg.display.set_mode(self.size, flags=pg.OPENGL | pg.DOUBLEBUF) if self.full else pg.display.set_mode(self.size, flags=pg.OPENGL | pg.DOUBLEBUF | pg.FULLSCREEN)
         self.ctx = mgl.create_context()
-        #self.ctx.front_face = 'cw' | mgl.CULL_FACE
-        self.ctx.enable(flags=mgl.DEPTH_TEST)
+        #self.ctx.front_face = 'cw'
+        self.ctx.enable(flags=mgl.DEPTH_TEST | mgl.CULL_FACE)
 
         self.clock = pg.time.Clock()
         self.camera = Camera(self)
