@@ -9,10 +9,10 @@ class ShaderProgram:
         self.programs['shadow_map'] = self.get_program('shadow_map')
 
     def get_program(self, shader_program_name):
-        with open(f'shaders/{shader_program_name}.vert') as file:
+        with open(f'accets/shaders/{shader_program_name}.vert') as file:
             vertex_shader = file.read()
 
-        with open(f'shaders/{shader_program_name}.frag') as file:
+        with open(f'accets/shaders/{shader_program_name}.frag') as file:
             fragment_shader = file.read()
 
         program = self.ctx.program(vertex_shader=vertex_shader, fragment_shader=fragment_shader)
